@@ -26,7 +26,7 @@ typedef struct {
 #undef XDG_VAR
 } xdg_t;
 
-xdg_t *xdg;
+extern xdg_t *xdg;
 
 #ifdef __cplusplus
 extern "C" {
