@@ -264,7 +264,7 @@ main(int argc, char **argv)
     else if ( write_file(output_file, cfg->data, cfg->len) == -1 )
         err(EXIT_FAILURE, _("Cannot write secret"));
 
-    if ( keep && argc >= optind ) {
+    if ( keep && optind >= argc ) {
         /* If we keep the file at the end and there is no command to
          * execute, we can leave here, there is no need to fork. */
         gfsec_secret_free(cfg);
