@@ -1,6 +1,6 @@
 /*
  * gfsecret - Secret sharing tools
- * Copyright (C) 2016 Damien Goutte-Gattat
+ * Copyright (C) 2016,2021 Damien Goutte-Gattat
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,7 +23,9 @@ typedef enum gfsec_scheme {
     GFSEC_SCHEME_FILE = 0,
     GFSEC_SCHEME_UUID,
     GFSEC_SCHEME_LABEL,
-    GFSEC_SCHEME_MTP
+    GFSEC_SCHEME_MTP,
+    GFSEC_SCHEME_HTTP,
+    GFSEC_SCHEME_HTTPS
 } gfsec_scheme_t;
 
 #define GFSEC_SCHEME_MAX 4
